import json
import uuid

import h2o_mlops_client as mlops

# Defines MLOps API URL. The address for the MLOps Gateway component.
# Usually: "https://api.mlops.my.domain"
MLOPS_API_URL = ""

# Defines IDP's token endpoint URL. For deployments using Keycloak as IDP:
# https://mlops.keycloak.domain/auth/realms/[fill-in-realm-name]/protocol/openid-connect/token
TOKEN_ENDPOINT_URL = ""

# Defines user's refresh token.
REFRESH_TOKEN = ""

# Sets client id for authentication.
CLIENT_ID = ""

# Sets client secret for authentication.
CLIENT_SECRET = ""

# Sets the id of the experiment
EXPERIMENT_ID = ""

# Set registered model id (Create a registered model if not exist)
REGISTERED_MODEL_ID = ""


# Creates model version for the given model and project id
def create_model_version(mlops_client: mlops.Client, model_version_request: mlops.StorageCreateModelVersionRequest):
    return mlops_client.storage.registered_model_version.create_model_version(model_version_request)


def create_model_version_request(registered_model_id, experiment_id):
    return mlops.StorageCreateModelVersionRequest(
        registered_model_version=mlops.StorageRegisteredModelVersion(
            registered_model_id=registered_model_id, experiment_id=experiment_id
        )
    )


def main():
    # Setting up the token provider using an existing refresh token.
    mlops_token_provider = mlops.TokenProvider(
        refresh_token=REFRESH_TOKEN,
        client_id=CLIENT_ID,
        client_secret=CLIENT_SECRET,
        token_endpoint_url=TOKEN_ENDPOINT_URL,
    )

    # Setting up MLOPS client.
    mlops_client = mlops.Client(
        gateway_url=MLOPS_API_URL,
        token_provider=mlops_token_provider,
    )

    # Creates registered model version for the given experiment and registered model
    create_model_version_response: mlops.StorageCreateModelVersionResponse = create_model_version(
        mlops_client=mlops_client,
        model_version_request=create_model_version_request(registered_model_id=REGISTERED_MODEL_ID,
                                                           experiment_id=EXPERIMENT_ID))
    print(create_model_version_response)


if __name__ == "__main__":
    main()